@@ -146,7 +146,8 @@ class Remote(object):
                     'rsync', '-lpthrvz', '--delete', '--safe-links',
                 ) + tuple('--exclude={0}'.format(e) for e in excludes) + (
                     '-e', ssh, local_dir,
-                    '{user}@{host}:{dest}/'.format(user=url['user'], host=url['host'], dest=url['path'])
+                    '{user}@{host}:{dest}/'.format(user=url['user'],
+                        host=url['host'], dest=url['path'])
                 )
         try:
             ret = subprocess.call(rsync, close_fds=True)
@@ -158,13 +159,10 @@ class Remote(object):
 
     def hg(self, local_dir, destination, args):
         self.info('# hg')
-        branch = args.get('branch')
         with utils.cd(local_dir):
             try:
                 ssh = ' '.join(self._ssh_options)
                 args = ('hg', 'push', '--ssh', ssh, '-f', destination)
-                if branch:
-                    args += ('-b', branch)
                 ret = subprocess.call(args, close_fds=True)
                 if ret != 0:
                     self.warning_ssh()
@@ -174,13 +172,11 @@ class Remote(object):
 
     def git(self, local_dir, destination, args):
         self.info('# git')
-        branch = args.get('branch')
-        if not branch:
-            branch = 'master'
         with utils.cd(local_dir):
             try:
                 os.environ['GIT_SSH'] = '__dotcloud_git_ssh'
-                ret = subprocess.call(('git', 'push', '-f', destination, branch), close_fds=True)
+                ret = subprocess.call(('git', 'push', '-f', '--all',
+                    destination), close_fds=True)
                 if ret != 0:
                     self.warning_ssh()
                 return ret
